# An assistment represents a single tutoring unit, including all problems
#  and scaffolding problems that make up the tutor
class Assistment < ActiveRecord::Base
  include ActionView::Helpers::TextHelper
  include ActionView::Helpers::SanitizeHelper
  
  has_many :problems, :dependent => :destroy
  has_one :problem, :conditions => 'scaffold_id is null'
  
  before_save  :timestamp
  after_create :create_problem
  
  # Give the assistment an autogenerated name if name isn't set
  def name
    return self[:name] unless self[:name].nil?
    return truncate(strip_tags(self.problem.body), 20) unless self.problem.nil? or self.problem.body.blank?
    "Assistment ##{id}"
  end
  
  # figures out the current problem the user is on in this assistment
  def current_problem(class_assignment, user)
    action = Action.find_by_class_assignment_id_and_user_id(class_assignment.id, user.id)
    action.action_problems.find_by_end_time(nil).problem
  end

protected
  
  def timestamp
    self.created_at = Time.now
  end
  
  def create_problem
    self.problems.create :name => "Main Problem"
  end
  
end
